/*************************************************************************
ENIB - Labos DSP
TI TMS320C6713
kerhoas@enib.fr
*************************************************************************/

#define CHIP_6713 1

#include <stdio.h>
#include <c6x.h>
#include <csl.h>
#include <csl_mcbsp.h>
#include <csl_irq.h>
#include <math.h>

#include "CONFIG_PROJET.h"
#include "table_sinus.h"
#include "partition.h"
#include "enveloppe.h"

#include "dsk6713.h"
#include "dsk6713_aic23.h"
#include "dsk6713_dip.h"
#include "dsk6713_led.h"

#define F_CPU   225000000.0
#define COEFF_TIMER 4.0

// CONSTANTES DE CALCUL
#define PI 3.141592654

// ROUTINES D'INTERRUPTION
interrupt void serialPortRcvISR(void);
interrupt void Timer0ISR(void);

// FONCTIONS
void IRQ_init();
void TIMER0_init(void);
void CODEC_init(void);
void TIMER0_relance(float);

// VARIABLES GLOBALES 
TIMER_Handle hTimer0 = NULL;

DSK6713_AIC23_CodecHandle hCodec;
DSK6713_AIC23_Config config = DSK6713_AIC23_CONFIG; 
 
float COUNT_TIMER=0 ;

/*-----------------------------------------------------------------
                        PROGRAMME PRINCIPAL 
-----------------------------------------------------------------*/

void main()
{

	DSK6713_init();				// Initialize the board support library, must be called first	
	//DSK6713_LED_init();      // LED Init 
	//DSK6713_DIP_init();      // BOUTONS Init
	TIMER0_init();
	CODEC_init();
	IRQ_init();


	IRQ_globalEnable();				// Globally enables interrupts

	while(1)						// main loop - do nothing but wait for interrupts
	{
	}
} 

/*-----------------------------------------------------------------
          ROUTINE INTERRUPTION CODEC (AU RYTHME DE Fe) 
-----------------------------------------------------------------*/

interrupt void serialPortRcvISR()
{
	union {Uint32 combo; short channel[2];} temp;
	float y;

	temp.combo = MCBSP_read(DSK6713_AIC23_DATAHANDLE);

/********************************************************
  A COMPLETER POUR TRAITEMENT DES ECHANTILLONS D'ENTREE
  y Rsultat du Calcul
********************************************************/

//	temp.channel[0]= (short)(y*16384.0) ;
//	temp.channel[1]= (short)(y*16384.0) ;

	MCBSP_write(DSK6713_AIC23_DATAHANDLE, temp.combo);

}

/*-----------------------------------------------------------------
           ROUTINE INTERRUPTION TIMER 
		   PERMET DE MODIFIER LA DUREE DES NOTES A JOUER
-----------------------------------------------------------------*/

interrupt void Timer0ISR()
{
/********************************************************
  A COMPLETER POUR LECTURE DE PARTITION
********************************************************/
}




/*-----------------------------------------------------------------
     PROGRAMMES D'INITIALISATION DES PERIPHERIQUES
-----------------------------------------------------------------*/


void TIMER0_init(void)
{
	TIMER_Config myTimerConfig;
	hTimer0= TIMER_open(TIMER_DEV0, TIMER_OPEN_RESET);
	TIMER_getConfig( hTimer0, &myTimerConfig);
	myTimerConfig.ctl &= 0xFF3F;
	myTimerConfig.ctl |= 0x200;
	myTimerConfig.prd = COUNT_TIMER;
	myTimerConfig.cnt = 0x00000000;
	TIMER_config(hTimer0, &myTimerConfig);
	TIMER_start(hTimer0);
	TIMER_pause(hTimer0);
}


void TIMER0_relance(float duree)
{
	COUNT_TIMER =(F_CPU * duree )/COEFF_TIMER;
	TIMER_setPeriod(hTimer0,(int) COUNT_TIMER);
	TIMER_resume(hTimer0);
}


void IRQ_init(void)
{
	// interrupt setup
	IRQ_globalDisable();			// Globally disables interrupts
	IRQ_nmiEnable();				// Enables the NMI interrupt
	IRQ_map(IRQ_EVT_RINT1,15);		// Maps an event to a physical interrupt
	IRQ_map(IRQ_EVT_TINT0,4);
	IRQ_enable(IRQ_EVT_RINT1);		// Enables the event
//	IRQ_enable(IRQ_EVT_TINT0); // --> DECOMMENTER POUR ISR TIMER0
}

void CODEC_init(void)
{
   hCodec = DSK6713_AIC23_openCodec(0, &config);	// open codec and get handle
	// Configure buffered serial ports for 32 bit operation
	// This allows transfer of both right and left channels in one read/write
	MCBSP_FSETS(SPCR1, RINTM, FRM);
	MCBSP_FSETS(SPCR1, XINTM, FRM);
	MCBSP_FSETS(RCR1, RWDLEN1, 32BIT);
	MCBSP_FSETS(XCR1, XWDLEN1, 32BIT);
	// set codec sampling frequency
	DSK6713_AIC23_setFreq(hCodec, DSK6713_AIC23_FREQ_44KHZ);
}


