/*************************************************************************
ENIB - Labos DSP
TI TMS320C6713
kerhoas@enib.fr
*************************************************************************/

#define CHIP_6713 1

#include <stdio.h>
#include <c6x.h>
#include <csl.h>
#include <csl_mcbsp.h>
#include <csl_irq.h>
#include <math.h>

#include "CONFIG_PROJET.h"
#include "COEFF_FILTER.h"


#include "dsk6713.h"
#include "dsk6713_aic23.h"
#include "dsk6713_dip.h"
#include "dsk6713_led.h"

#define F_CPU   225000000.0
#define COEFF_TIMER 4.0

// CONSTANTES DE CALCUL
#define PI 3.141592654

// ROUTINES D'INTERRUPTION
interrupt void serialPortRcvISR(void);
interrupt void Timer0ISR(void);

// FONCTIONS
void IRQ_init();
void CODEC_init(void);
void TIMER0_relance(float);

int fir_int_circ(int *, int );


// VARIABLES GLOBALES 

DSK6713_AIC23_CodecHandle hCodec;
DSK6713_AIC23_Config config = DSK6713_AIC23_CONFIG; 
 
float COUNT_TIMER=0 ;

float registre_circ[N_filter];

/*-----------------------------------------------------------------
                        PROGRAMME PRINCIPAL 
-----------------------------------------------------------------*/

void main()
{	int i=0;

	DSK6713_init();		// Initialize the board support library, must be called first	
	DSK6713_LED_init();
	DSK6713_DIP_init();
	CODEC_init();
	IRQ_init();

		/* Clear the buffers*/
	for (i = 0; i < N_filter; i++ ){
		registre_circ[i] = 0;
		}


	IRQ_globalEnable();				// Globally enables interrupts

	while(1)						// main loop - do nothing but wait for interrupts
	{
	}
} 

/*-----------------------------------------------------------------
          ROUTINE INTERRUPTION CODEC (AU RYTHME DE Fe) 
-----------------------------------------------------------------*/

interrupt void serialPortRcvISR()
{
	union {Uint32 combo; short channel[2];} temp;
	int y;
	static int sample_number=0;   

	temp.combo = MCBSP_read(DSK6713_AIC23_DATAHANDLE);

	y=fir_int_circ(&sample_number,(int)temp.channel[0]);

	temp.channel[0]= (short)(y>>15) ;
	temp.channel[1]= (short)(y>>15) ;

	MCBSP_write(DSK6713_AIC23_DATAHANDLE, temp.combo);

}

/*-----------------------------------------------------------------
         FONCTION DE FILTRAGE
-----------------------------------------------------------------*/

int fir_int_circ(int *numero_ech, int echantillon)

{	

		int yn = 0;                  
		int i=0;
		int x_index = 0;	
		

		registre_circ[*numero_ech] =(short) echantillon;
		x_index = *numero_ech;
		for (i = 0; i < N_filter; i++)
					{
			
			yn += h[i] * registre_circ[x_index];
			-- x_index;							
			if(x_index == -1) x_index = N_filter-1;																									
										
					}

		*numero_ech = *numero_ech+1;
		if (*numero_ech==N_filter) {*numero_ech=0;}

	return yn;

}

/*-----------------------------------------------------------------
     PROGRAMMES D'INITIALISATION DES PERIPHERIQUES
-----------------------------------------------------------------*/


void IRQ_init(void)
{
	// interrupt setup
	IRQ_globalDisable();			// Globally disables interrupts
	IRQ_nmiEnable();				// Enables the NMI interrupt
	IRQ_map(IRQ_EVT_RINT1,15);		// Maps an event to a physical interrupt
	IRQ_map(IRQ_EVT_TINT0,4);
	IRQ_enable(IRQ_EVT_RINT1);		// Enables the event
//	IRQ_enable(IRQ_EVT_TINT0); // --> DECOMMENTER POUR ISR TIMER0
}

void CODEC_init(void)
{
   hCodec = DSK6713_AIC23_openCodec(0, &config);	// open codec and get handle
	// Configure buffered serial ports for 32 bit operation
	// This allows transfer of both right and left channels in one read/write
	MCBSP_FSETS(SPCR1, RINTM, FRM);
	MCBSP_FSETS(SPCR1, XINTM, FRM);
	MCBSP_FSETS(RCR1, RWDLEN1, 32BIT);
	MCBSP_FSETS(XCR1, XWDLEN1, 32BIT);
	// set codec sampling frequency
	DSK6713_AIC23_setFreq(hCodec, DSK6713_AIC23_FREQ_24KHZ);
}


